/*
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details:
 *
 *  http://www.gnu.org/copyleft/gpl.txt
 */

#include "common.h"

/*-------------------------------------------------------------------------*/

/* Runtime config data */
extern rc_data_t rc_data;

/* Global widgets */
extern GtkWidget
  *main_window,
  *popup_menu;

extern GtkBuilder
  *main_window_builder,
  *popup_menu_builder;

/* QSO data record */
extern qso_record_t qso_record;

/* File desc of external log-file to be imported */
extern FILE *ext_log_fp;

/*-------------------------------------------------------------------------*/

